==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AFieldReference.h <==
// public final class soot.jimple.parser.node.AFieldReference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef298bd70499c824 soot_jimple_parser_node_AFieldReference
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 2a4c678c0b032ea5 soot_jimple_parser_node_PReference

// header file dependencies
// @dep_header soot_jimple_parser_node_PReference

#include "soot/jimple/parser/node/PReference.h"

#ifndef _JC_soot_jimple_parser_node_AFieldReference_H_
#define _JC_soot_jimple_parser_node_AFieldReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PFieldRef$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFieldReference$sub_refs	_jc_soot_jimple_parser_node_AFieldReference$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs	_jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$refs	_jc_soot_jimple_parser_node_AFieldReference$refs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$nonrefs	_jc_soot_jimple_parser_node_AFieldReference$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$object	_jc_soot_jimple_parser_node_AFieldReference$object;

typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vmethods	_jc_soot_jimple_parser_node_AFieldReference$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vtable	_jc_soot_jimple_parser_node_AFieldReference$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vtype	_jc_soot_jimple_parser_node_AFieldReference$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFieldReference$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
extern void _jc_soot_jimple_parser_node_AFieldReference$method$_init$1a90d6d5094b2fb3(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFieldReference$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFieldReference$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
extern struct _jc_soot_jimple_parser_node_PFieldRef$object *_jc_soot_jimple_parser_node_AFieldReference$method$getFieldRef$ba990be9a0f37db4(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
extern void _jc_soot_jimple_parser_node_AFieldReference$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFieldReference$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFieldReference$method$setFieldRef$578a195b779fd315(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFieldReference$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$getFieldRef$ba990be9a0f37db4;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$setFieldRef$578a195b779fd315;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFieldReference$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
	struct _jc_soot_jimple_parser_node_PFieldRef$object	*(*getFieldRef$ba990be9a0f37db4)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFieldRef$578a195b779fd315)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AFieldReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PReference$vmethods	soot_jimple_parser_node_PReference;
	_jc_soot_jimple_parser_node_AFieldReference$vmethods	soot_jimple_parser_node_AFieldReference;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFieldReference$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFieldReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFieldReference$sub_refs {
	struct _jc_soot_jimple_parser_node_PFieldRef$object	*__5ffieldRef__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFieldReference$refs {
    _jc_soot_jimple_parser_node_AFieldReference$sub_refs	soot_jimple_parser_node_AFieldReference;
    _jc_soot_jimple_parser_node_PReference$sub_refs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFieldReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PReference$sub_nonrefs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs	soot_jimple_parser_node_AFieldReference;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFieldReference$object {
	_jc_soot_jimple_parser_node_AFieldReference$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFieldReference$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFieldReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFieldReference$vtype _jc_soot_jimple_parser_node_AFieldReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFieldReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFieldReference$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFieldReference_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AFieldReference.h <==
// public final class soot.jimple.parser.node.AFieldReference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef298bd70499c824 soot_jimple_parser_node_AFieldReference
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 2a4c678c0b032ea5 soot_jimple_parser_node_PReference

// header file dependencies
// @dep_header soot_jimple_parser_node_PReference

#include "soot/jimple/parser/node/PReference.h"

#ifndef _JC_soot_jimple_parser_node_AFieldReference_H_
#define _JC_soot_jimple_parser_node_AFieldReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PFieldRef$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFieldReference$sub_refs	_jc_soot_jimple_parser_node_AFieldReference$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs	_jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$refs	_jc_soot_jimple_parser_node_AFieldReference$refs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$nonrefs	_jc_soot_jimple_parser_node_AFieldReference$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFieldReference$object	_jc_soot_jimple_parser_node_AFieldReference$object;

typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vmethods	_jc_soot_jimple_parser_node_AFieldReference$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vtable	_jc_soot_jimple_parser_node_AFieldReference$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFieldReference$vtype	_jc_soot_jimple_parser_node_AFieldReference$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFieldReference$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFieldReference$method$_init$1a90d6d5094b2fb3(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFieldReference$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFieldReference$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PFieldRef$object *_jc_soot_jimple_parser_node_AFieldReference$method$getFieldRef$ba990be9a0f37db4(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFieldReference$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFieldReference$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFieldReference$method$setFieldRef$578a195b779fd315(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFieldReference$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$getFieldRef$ba990be9a0f37db4;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$setFieldRef$578a195b779fd315;
extern _jc_method _jc_soot_jimple_parser_node_AFieldReference$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFieldReference$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PFieldRef$object	*(*getFieldRef$ba990be9a0f37db4)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFieldRef$578a195b779fd315)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *, struct _jc_soot_jimple_parser_node_PFieldRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFieldReference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AFieldReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PReference$vmethods	soot_jimple_parser_node_PReference;
	_jc_soot_jimple_parser_node_AFieldReference$vmethods	soot_jimple_parser_node_AFieldReference;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFieldReference$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFieldReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFieldReference$sub_refs {
	struct _jc_soot_jimple_parser_node_PFieldRef$object	*__5ffieldRef__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFieldReference$refs {
    _jc_soot_jimple_parser_node_AFieldReference$sub_refs	soot_jimple_parser_node_AFieldReference;
    _jc_soot_jimple_parser_node_PReference$sub_refs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFieldReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PReference$sub_nonrefs	soot_jimple_parser_node_PReference;
    _jc_soot_jimple_parser_node_AFieldReference$sub_nonrefs	soot_jimple_parser_node_AFieldReference;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFieldReference$object {
	_jc_soot_jimple_parser_node_AFieldReference$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFieldReference$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFieldReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFieldReference$vtype _jc_soot_jimple_parser_node_AFieldReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFieldReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFieldReference$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFieldReference_H_ */
